--- loncom/publisher/lonpubdir.pm	2012/10/29 17:38:55	1.144
+++ loncom/publisher/lonpubdir.pm	2014/01/21 18:23:35	1.149
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.144 2012/10/29 17:38:55 raeburn Exp $
+# $Id: lonpubdir.pm,v 1.149 2014/01/21 18:23:35 musolffc Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -46,7 +46,7 @@ sub handler {
 
   my $r=shift;
 
-  # Validate access to the construction space and get username@domain.
+  # Validate access to the construction space and get username:domain.
 
   my $uname;
   my $udom;
@@ -97,6 +97,7 @@ sub handler {
   opendir(DIR,$fn);
   my @files=sort {uc($a) cmp uc($b)} (readdir(DIR));
   foreach my $filename (@files) {
+     next if ($filename eq '.DS_Store');
      my ($cdev,$cino,$cmode,$cnlink,
          $cuid,$cgid,$crdev,$csize,
          $catime,$cmtime,$cctime,
@@ -143,20 +144,28 @@ sub startpage {
 
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb({
-        'text'  => 'Construction Space',
+        'text'  => 'Authoring Space',
         'href'  => &Apache::loncommon::authorspace($formaction),
     });
     # breadcrumbs (and tools) will be created 
     # in start_page->bodytag->innerregister
 
     $env{'request.noversionuri'}=$formaction;
-    $r->print(&Apache::loncommon::start_page('Construction Space',undef));
+    $r->print(&Apache::loncommon::start_page('Authoring Space',undef));
+
+    my $londocroot = $Apache::lonnet::perlvar{'lonDocRoot'};
+    my $current_disk_usage = &Apache::lonnet::diskusage($udom,$uname,"$londocroot/priv/$udom/$uname");
+    my $disk_quota = &Apache::loncommon::get_user_quota($uname,$udom,'author'); #expressed in Mb
+    $disk_quota = 1000 * $disk_quota; # convert from Mb to kb
 
     $r->print(&Apache::loncommon::head_subbox(
-                &Apache::loncommon::CSTR_pageheader()));
+                     '<div style="float:right;padding-top:0;margin-top;0">'
+                    .&Apache::lonhtmlcommon::display_usage($current_disk_usage,$disk_quota)
+                    .'</div>'
+                    .&Apache::loncommon::CSTR_pageheader()));
 
     my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
-    my $doctitle = 'LON-CAPA '.&mt('Construction Space');
+    my $doctitle = 'LON-CAPA '.&mt('Authoring Space');
     my $newname = &mt('New Name');
     my $pubdirscript=(<<ENDPUBDIRSCRIPT);
 <script type="text/javascript">
@@ -616,11 +625,11 @@ sub putresource {
     my $editlink='';
     my $editlink2='';
     if ($filename=~/\.(xml|html|htm|xhtml|xhtm|sty)$/) {
-	$editlink=' <br />(<a href="'.$linkdir.'/'.$filename.'?editmode=Edit&problemmode=edit">'.&mt('Edit').'</a>)';
+	$editlink=' <br />(<a href="'.$linkdir.'/'.$filename.'?editmode=Edit&amp;problemmode=edit">'.&mt('Edit').'</a>)';
     }
     if ($filename=~/$LONCAPA::assess_re/) {
-	$editlink=' (<a href="'.$linkdir.'/'.$filename.'?editmode=Edit&problemmode=editxml">'.&mt('EditXML').'</a>)';
-	$editlink2=' <br />(<a href="'.$linkdir.'/'.$filename.'?editmode=Edit&problemmode=edit">'.&mt('Edit').'</a>)';
+	$editlink=' (<a href="'.$linkdir.'/'.$filename.'?editmode=Edit&amp;problemmode=editxml">'.&mt('EditXML').'</a>)';
+	$editlink2=' <br />(<a href="'.$linkdir.'/'.$filename.'?editmode=Edit&amp;problemmode=edit">'.&mt('Edit').'</a>)';
     }
     if ($filename=~/\.(problem|exam|quiz|assess|survey|form|library|xml|html|htm|xhtml|xhtm|sty)$/) {
 	$editlink.=' (<a href="/adm/cleanup?filename='.$linkfilename.'" target="_parent">'.&mt('Clean Up').')</a>';
@@ -706,7 +715,7 @@ __END__
 
 =head1 NAME
 
-Apache::lonpubdir - Construction space directory lister
+Apache::lonpubdir - Authoring space directory lister
 
 =head1 SYNOPSIS
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
-# Construction Space Directory Lister
+# Authoring Space Directory Lister
 #